@@ -1,14 +1,15 @@
 """剿灭、蚀刻章、合约等活动到期提醒"""
-import nonebot
-from nonebot.log import logger
-from nonebot import on_regex
-from nonebot_plugin_apscheduler import scheduler
 import os
 
+import nonebot
+from nonebot import on_regex
+from nonebot.adapters.onebot.v11 import Message
+from nonebot.log import logger
+from nonebot_plugin_apscheduler import scheduler
+
 from .config import Config
 from .data_source import get_activities
 
-
 global_config = nonebot.get_driver().config
 activity_config = Config(**global_config.dict())
 
@@ -18,10 +19,16 @@ latest_activity = on_regex(r'[查看询]*方舟[最]*新+[活动闻]*', priority
 @latest_activity.handle()
 async def _():
     rst_msg = await get_activities(is_force=True)
-    if rst_msg:
-        await latest_activity.finish(rst_msg)
+    if isinstance(rst_msg, Message):
+        rst = rst_msg
+    elif isinstance(rst_msg, str):
+        rst = (
+            f"方舟最新活动截图失败！\n请更换至非windows平台部署本插件\n或检查网络连接并稍后重试"
+            f"最新的活动信息请见链接: {rst_msg}"
+        )
     else:
-        await latest_activity.finish(f"方舟最新活动截图失败！请更换至非windows平台部署本插件\n或检查网络连接并稍后重试", at_sender=True)
+        rst = "无法获得方舟最新活动信息！请稍后重试"
+    await latest_activity.finish(rst)
 
 
 @scheduler.scheduled_job(
